import {onMount, onCleanup} from "solid-js";

import styles from "./RightPane.module.css";
import input_styles from "./input/input.module.css";

import {World} from "../stackline-wasm/stackline_wasm.js";

export default function Controls(props) {
    let {settings, setSettings, world, setWorld} = props;
    let save_button, reload_button;

    function save() {
        console.log("save");
        window.localStorage.setItem("world", JSON.stringify(world().serialize()));
    }

    function reload() {
        let new_world = window.localStorage.getItem("world");
        if (!new_world) return;

        new_world = JSON.parse(new_world);
        new_world = World.deserialize(new_world);

        setWorld(world => {
            if (world.ptr) {
                world.free();
            }

            return new_world;
        });
    }

    function key_down(evt) {
        if (evt.code === "KeyS" && evt.ctrlKey) {
            evt.preventDefault();

            save_button.classList.add(input_styles.active);
            save();
            setTimeout(() => {
                save_button.classList.remove(input_styles.active);
            }, 200);
        }

        if (evt.code === "KeyR" && evt.ctrlKey) {
            evt.preventDefault();

            reload_button.classList.add(input_styles.active);
            reload();
            setTimeout(() => {
                reload_button.classList.remove(input_styles.active);
            }, 200);
        }
    }

    onMount(() => {
        window.addEventListener("keydown", key_down, {capture: true});
    });

    onCleanup(() => {
        window.removeEventListener("keydown", key_down);
    });

    return <div>
        <button ref={save_button} class={input_styles.button} onClick={save}>Save</button>
        <button ref={reload_button} class={input_styles.button} onClick={reload}>Reload</button>
    </div>
}
