import {onMount, onCleanup} from "solid-js";
import Tabbed from "./Tabbed.jsx";

import Presets, {init} from "./Presets.jsx";
import Panes from "./Panes.jsx";

import styles from "./LeftPane.module.css";

export {init};

export default function LeftPane(props) {
    let [preset_picker, presets] = Presets(props);
    let container;

    function resize() {
        let width = document.body.clientWidth / 4;
        if (width >= 390) {
            width = 390;
        } else if (width >= 255) {
            width = 255;
        } else {
            width = 125;
        }

        container.style.width = `calc(${Math.round(width)}px + 2em)`;
    }

    onMount(() => {
        setTimeout(() => {
            window.addEventListener("resize", resize);
            resize();
        }, 0);
    });

    onCleanup(() => {
        window.removeEventListener("resize", resize);
    });

    return [<div class={styles.LeftPane_container}><div
        class={styles.LeftPane}
        ref={container}
    >
        <Tabbed>
            <div title="Presets">{preset_picker}</div>
            <div title="Panes">
                <Panes world={props.world} setWorld={props.setWorld} />
            </div>
        </Tabbed>
    </div></div>, presets];
}
