import {createSignal} from "solid-js";
import {createStore} from "solid-js/store";

import styles from "./LeftPane.module.css";

import {available_tiles, Pane, FullTile} from "../stackline-wasm/stackline_wasm.js";
import TilePreset from "./TilePreset.jsx";

export const BASE_TILES = [];

export class Tile {
    constructor(serialized, name) {
        this.serialized = serialized;
        this.name = name;
    }
}

export function init() {
    let pane = new Pane(1, 1);
    BASE_TILES.push(new Tile(pane.serialize(), "Empty"));
    pane.free();

    for (let name of available_tiles().sort()) {
        let pane = new Pane(1, 1);

        let tile = new FullTile(name);
        pane.set(0, 0, tile);

        let serialized = pane.serialize();

        pane.free();
        BASE_TILES.push(new Tile(serialized, name));
    }
}

export default function Presets(props) {
    let [presets, setPresets] = createStore(BASE_TILES);
    let {settings, setSettings} = props;

    return [<div class={styles.Presets}>
        <For each={BASE_TILES}>
            {(item, index) => {
                return <TilePreset pane={() => item.serialized} name={() => item.name} settings={settings} setSettings={setSettings} index={index} />;
            }}
        </For>
    </div>, presets];
}
