import {createEffect, createSignal, createMemo, untrack} from "solid-js";

import Tile from "./Tile.jsx";
import Signal from "./Signal.jsx";
import styles from "./RightPane.module.css";

export default function RightPane(props) {
    let {settings, setSettings, world, setWorld} = props;

    let selected = createMemo((old) => {
        if (old?.ptr) {
            old.free();
        }

        if (settings.selected) {
            return world().get(...settings.selected) ?? null;
        } else {
            return null;
        }
    }, {equals: false});

    let signal = createMemo((old) => {
        if (old?.ptr) {
            old.free();
        }

        if (selected()) {
            return selected().signal ?? null;
        } else {
            return null;
        }
    }, {equals: false});

    function setSignal(new_signal) {
        setWorld((world) => {
            let [x, y] = settings.selected;
            let full_tile = world.get(x, y);
            let had_signal = !!full_tile.signal;

            if (typeof new_signal === "function") {
                full_tile.signal = new_signal(full_tile.signal);
            } else {
                full_tile.signal = new_signal;
            }

            if (full_tile.signal && !had_signal) {
                full_tile.state = "Active";
            }

            world.set(x, y, full_tile);
            return world;
        });
    }

    function set_full_tile(tile) {
        if (settings.selected) {
            setWorld((world) => {
                let [x, y ] = settings.selected;
                if (typeof tile === "function") {
                    // world.get(...) is passed by ownership, and an owned value is expected back
                    world.set(x, y, tile(world.get(x, y)));
                } else {
                    world.set(x, y, tile);
                }
                return world;
            });
        }
    };

    function cleanup() {
        let sel = selected();
        if (sel.ptr) {
            sel.free();
        }

        let sig = signal();
        if (sig.ptr) {
            sig.free();
        }
    }

    return (<div class={styles.Properties}>
        <Show when={selected() !== null} fallback={<i class={styles.gray}>Nothing selected</i>} onCleanup={cleanup}>
            <h2 class={styles.h2}>Coordinates:</h2>
            ({settings.selected[0]}, {settings.selected[1]})
            <h2 class={styles.h2}>State:</h2>
            {selected().state}
            <h2 class={styles.h2}>Signal:</h2>
            <Signal signal={signal} setSignal={setSignal} />
            <Tile full_tile={selected} set_full_tile={set_full_tile} />
        </Show>
    </div>);
}
