import {createEffect, createMemo, createUniqueId} from "solid-js";

import {Pane} from "../stackline-wasm/stackline_wasm.js";

import styles from "./LeftPane.module.css";

export default function TilePreset(props) {
    let {settings, setSettings, index} = props;

    let rendered = createMemo(() => {
        let pane = Pane.deserialize(props.pane());

        let text = pane.to_text();
        let width = pane.width;
        let height = pane.height;

        pane.free();

        return {text, width, height};
    });

    let id = createUniqueId();

    let preview;

    return (<div
        class={styles.TilePreset}
        class={settings.picked === index() ? styles.picked : ""}
        onClick={() => {
            if (settings.picked !== index()) {
                setSettings("picked", index());
            } else {
                setSettings("picked", null);
            }
        }}
        draggable="true"
        onDragStart={(evt) => {
            evt.dataTransfer.setData("application/json", JSON.stringify(props.pane()));
            evt.dataTransfer.dropEffect = "copy";

            const TILE_SIZE = 50;
            let canvas = document.createElement("canvas");
            canvas.width = TILE_SIZE * rendered().width;
            canvas.height = TILE_SIZE * rendered().height;

            let ctx = canvas.getContext("2d");
            ctx.font = `${TILE_SIZE}px Stackline Classic`;

            ctx.textAlign = "left";
            ctx.textBaseline = "top";

            ctx.fillStyle = "white";
            ctx.fillText(rendered().text, 0, 0);

            evt.dataTransfer.setDragImage(canvas, canvas.width / 2, canvas.height / 2);
        }}
    >
        <pre ref={preview} class={styles.preview} style={{width: 30 * rendered().width + "px"}} id={id}>{rendered().text}</pre>
        <div>{props.name}</div>
    </div>);
}
